==> bloobasket-1.0.0.tgz: package/index.js <==
var bloosql = require('bloosql');
var randomstring = require('randomstring');
var config;

function configBasket(basketTable, basketItemsTable, basketIdentifier, basketRef, db, dbUser, dbPassword, callback){
    config = {
        basket : basketTable, /*for example 'blooware.basket'*/
        basketIdRow : basketIdentifier, /*for example 'basket'*/
        basketRef : basketRef, /*for example 'basket'*/
        basket_items : basketItemsTable/*for example 'blooware.basket_items'*/
    }
    bloosql.setup(db,dbUser,dbPassword,3306,function(){callback(true)});

} /*setup basket*/

function createBasket(data, callback){
    bloosql.query("insert into ?? set ?, ref = ?",[config.basket, data, randomstring.generate(30)],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(false);
        }
        else{            
            callback(true);
        }
    });
} /*create a new basket*/

function getBasket(user, callback){
    bloosql.query("select * from ?? where user_id = ? order by id desc limit 1 ",[config.basket, user],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(rows[0]);
        }
        else{            
            callback(rows[0]);
        }
    });
}

function deleteBasket(id, callback){
    bloosql.query("delete from ?? where ?? = ?; ",[config.basket_items, config.basketIdRow, id],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);

        }
        else{            
            deleteBask();
        }
    });

    function deleteBask(){
        bloosql.query(" delete from ?? where ?? = ?;",[config.basket, config.basketRef, id],function(rows, err, q){

            if(err){
                console.log("Error in Bloobasket : %s ", err);
                callback(false);
            }
            else{            
                callback(true);
            }
        });
    }
} /* delete a specific basket*/

function addToBasket(item, callback){
    bloosql.query("insert into ?? set ? ",[config.basket_items, item],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(false);
        }
        else{            
            callback(true);
        }
    });
} /*add item to basket*/

function getBasketItems(basketId, callback){
    bloosql.query("select * from ?? where ?? = ?",[config.basket_items, config.basketIdRow, basketId],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
        }
        else{            
            callback(rows);
        }
    });
} /*return all items in a basket*/

function removeFromBasket(item, callback){
    bloosql.query("delete from ?? where id = ? ",[config.basket_items, item],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(false);
        }
        else{            
            callback(true);
        }
    });
} /*remove item from basket*/


configBasket("pepper.basket", "pepper.basket_items", "basket","ref", "pepper.c2qh4vkdvsoy.eu-west-2.rds.amazonaws.com", "bloo18", "bloo2016", function(complete){
    console.log("Success: " + complete);
});


/*
addToBasket({item: 3, basket : "2FompAgck1vRvRr6lr06CatR6DZJR8"}, function(complete){
    console.log(complete);
})*/

==> bloobasket-1.1.0.tgz: package/index.js <==
var bloosql = require('bloosql');
var randomstring = require('randomstring');
var config;

function configBasket(basketTable, basketItemsTable, basketIdentifier, basketRef, itemsTable, db, dbUser, dbPassword, callback){
    config = {
        basket : basketTable, /*for example 'blooware.basket'*/
        basketIdRow : basketIdentifier, /*for example 'basket'*/
        basketRef : basketRef, /*for example 'basket'*/
        basket_items : basketItemsTable,/*for example 'blooware.basket_items'*/
        itemsTable : itemsTable/*for example 'blooware.basket_items'*/
    }
    bloosql.setup(db,dbUser,dbPassword,3306,function(){callback(true)});

} /*setup basket*/

function createBasket(data, callback){
    bloosql.query("insert into ?? set ?, ref = ?",[config.basket, data, randomstring.generate(30)],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(false);
        }
        else{            
            callback(true);
        }
    });
} /*create a new basket*/

function getBasket(user, callback){
    bloosql.query("select * from ?? where user_id = ? order by id desc limit 1 ",[config.basket, user],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(rows[0]);
        }
        else{            
            callback(rows[0]);
        }
    });
}

function deleteBasket(id, callback){
    bloosql.query("delete from ?? where ?? = ?; ",[config.basket_items, config.basketIdRow, id],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);

        }
        else{            
            deleteBask();
        }
    });

    function deleteBask(){
        bloosql.query(" delete from ?? where ?? = ?;",[config.basket, config.basketRef, id],function(rows, err, q){

            if(err){
                console.log("Error in Bloobasket : %s ", err);
                callback(false);
            }
            else{            
                callback(true);
            }
        });
    }
} /* delete a specific basket*/

function addToBasket(item, callback){
    bloosql.query("insert into ?? set ? ",[config.basket_items, item],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(false);
        }
        else{            
            callback(true);
        }
    });
} /*add item to basket*/

function getBasketItems(basketId, callback){
    bloosql.query("select * from ?? where ?? = ?",[config.basket_items, config.basketIdRow, basketId],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
        }
        else{            
            callback(rows);
        }
    });
} /*return all items in a basket*/

function removeFromBasket(item, callback){
    bloosql.query("delete from ?? where id = ? ",[config.basket_items, item],function(rows, err, q){
        if(err){
            console.log("Error in Bloobasket : %s ", err);
            callback(false);
        }
        else{            
            callback(true);
        }
    });
} /*remove item from basket*/

function checkOut(basketId, itemsTableId, basket_itemsId, callback){
    var items;
    var cost;

    function getItems(callback){
        bloosql.query("select * from ?? inner join ?? on ??=?? where basket = ?",[config.basket_items, config.itemsTable, itemsTableId, basket_itemsId, basketId],function(rows, err, q){

            if(err){
                console.log("Error in Bloobasket : %s ", err);
            }
            else{  
                items = rows;
                callback();
            }
        }); 
    }

    function getCost(callback){
        bloosql.query("select sum(price) as price from ?? inner join ?? on ??=?? where basket = ?",[config.basket_items, config.itemsTable, itemsTableId, basket_itemsId, basketId],function(rows, err, q){

            if(err){
                console.log("Error in Bloobasket : %s ", err);
            }
            else{  
                /**/
                cost = rows[0].price;
                callback();
            }
        });
    }
    
    function finish(){
        callback({cost : cost, items : items});
    }
    
    getItems(function(){getCost(function(){finish()})});

}
